=============
 oslo.policy
=============

An OpenStack library providing support for RBAC policy enforcement across all
OpenStack services.

.. toctree::
   :maxdepth: 2

   install/index
   admin/index
   configuration/index
   cli/index
   user/index
   reference/index
   contributor/index

.. rubric:: Indices and tables

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
